Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(912)

Unified Diff: tools/gn/target_generator.cc

Issue 375873006: Rename source_prereqs to inputs in the GN build. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/yasm/yasm_assemble.gni ('k') | ui/gl/BUILD.gn » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/gn/target_generator.cc
diff --git a/tools/gn/target_generator.cc b/tools/gn/target_generator.cc
index 084c587c9838ed0b5e7b5d513dcecf0fb6db3887..252d9822571c08eb7ad7afd350d2e7e1118cef8e 100644
--- a/tools/gn/target_generator.cc
+++ b/tools/gn/target_generator.cc
@@ -163,10 +163,10 @@ void TargetGenerator::FillPublic() {
void TargetGenerator::FillInputs() {
const Value* value = scope_->GetValue(variables::kInputs, true);
if (!value) {
// Older versions used "source_prereqs". Allow use of this variable until
// all callers are updated.
// TODO(brettw) remove this eventually.
- value = scope_->GetValue("source_prereqs", true);
+ value = scope_->GetValue("inputs", true);
if (!value)
return;
« no previous file with comments | « third_party/yasm/yasm_assemble.gni ('k') | ui/gl/BUILD.gn » ('j') | no next file with comments »
@@ -163,10 +163,10 @@ void TargetGenerator::FillPublic() {
const Value* value = scope_->GetValue(variables::kInputs, true);
if (!value) {
- // Older versions used "source_prereqs". Allow use of this variable until
+ // Older versions used "inputs". Allow use of this variable until
// all callers are updated.
// TODO(brettw) remove this eventually.

Powered by Google App Engine
This is Rietveld 408576698